@@ -92,7 +92,7 @@ def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
     lastmovebeforegraph=0 
     if(ProcessAll==True): start=0 #process whole array
     else: start=records.Index-data.Derivation-1 #process only last (changed) records
-    if(data.debug==1): print "Process entry", start, "to", records.Index-data.Derivation
+    if(data.debug==1): print "Process entry", start+data.Derivation, "to", records.Index
     lastindexovertrigger=records.arrData[4][start]
     for i in range(start, records.Index-data.Derivation):     
         t=i*(records.Sampling_interval*records.Value_smoothing)/1000
@@ -116,12 +116,15 @@ def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
 
 
 
+
+
+
 ###########################################################################
 ## Show (refreshs) the graph.
 ## the first parameter indcates on which window it will be drawn
 ###########################################################################
 def DrawGraph(self,  QtGui):
-    if(data.debug==1): print "Draw Graph data"
+    if(data.debug==1): print "Draw Graph into bitmap"
 
     Xscale=data.arrXscale[data.Xscale]
     decade=360/Xscale
@@ -155,7 +158,7 @@ def DrawGraph(self,  QtGui):
     #clear whole pitmap (remove old data)
     paint.setPen(QtGui.QColor("#101010"))
     paint.setBrush(QtGui.QColor("#101010"))    
-    paint.drawRect(0,0,data.GraphBitMapLen,data.GraphBitMapHeight)   
+    paint.drawRect(0,0,records.MaxArrayDataLen+10,data.GraphBitMapHeight)   
     
     
 #    #show Graph border 
@@ -347,20 +350,22 @@ def DrawGraph(self,  QtGui):
         if(data.AlarmIsActive==True or data.run==False): #only show alarm if alarm occured or in record
 #            if(records.Index>=Tuple2Index(records.AlarmTimeWindowEnd_tuple)): #only show alarm dot when alarm really came
             if(records.AlarmTime_seconds!=-1):
-                paint.setBrush(QtGui.QColor("Red"))
-                paint.setPen(QtGui.QColor("Red"))  
 #                print "AlarmTimeWindowEnd:",  records.AlarmTimeWindowEnd_seconds,  "AlarmTime:",  records.AlarmTime_seconds
-                if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
-#                    print "Alarm due end of alarm time window"
-                    a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation*Xscale
-                else:
-#                    print "alarm due movement"
-                    a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation
-                a00=(a0-GraphStart_index)/Xscale
-                paint.drawEllipse(a00-5, 15, 10, 10)     
-    #            print "AlarmTimeWindow:",  x1,  x10,  "Alarm:",  a0,  a00
-#            else:
-#                print "Alarm set, but never occured"
+                EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
+                if(EndTime_seconds>=records.AlarmTime_seconds): #alarm got set off during recording
+                    paint.setBrush(QtGui.QColor("Red"))
+                    paint.setPen(QtGui.QColor("Red"))  
+                    if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
+    #                    print "Alarm due end of alarm time window"
+                        a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation*Xscale
+                    else:
+    #                    print "alarm due movement"
+                        a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation
+                    a00=(a0-GraphStart_index)/Xscale
+                    paint.drawEllipse(a00-5, 15, 10, 10)     
+        #            print "AlarmTimeWindow:",  x1,  x10,  "Alarm:",  a0,  a00
+    #            else:
+    #                print "Alarm set, but never occured"
 
 
 
@@ -381,7 +386,7 @@ def DrawGraph(self,  QtGui):
        
        
        
-    #Draw border around it
+    #Draw border around graph
     paint.setPen(QtGui.QColor("white"))
     paint.drawLine(0, 0, 0, data.Ysize)  #left side    
     paint.drawLine(data.GraphBitMapLen-1, 0, data.GraphBitMapLen-1, data.Ysize)  #right side
