@@ -178,7 +178,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
         
         WriteIntoRecordFile()
         
-        GraphLen=records.Index/data.arrXscale[data.Xscale]
+#        GraphLen=records.Index/data.arrXscale[data.Xscale]
 #        data.GraphStart=max(GraphLen-779, 0)
         
         data.ScrollToEnd=True
@@ -638,9 +638,11 @@ class frmRecordWindow(QMainWindow):
         
     def UpdateScreen(self):    
         if(data.DisplayIsOn==False):
-            if(data.debug==1): print "-> Do not update screen, Display is off!"
+            if(data.debug==1): print "-> x Do not update screen, Display is off!"
             return
-            
+        else:
+            if(data.debug==1): print "-> o Update screen"
+        
         if(data.run==True): #recording
             t=time.mktime(time.localtime())
             time_difference=t-data.StartTimeSec
@@ -1355,7 +1357,8 @@ class frmAdditionalInfoWindow(QMainWindow):
         shortfolder=string.replace(shortfolder, "//", "/") #workaround
         
         d0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.StartTime_tuple)
-        EndTime_tuple=Seconds2Tuple(Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000)
+        EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
+        EndTime_tuple=Seconds2Tuple(EndTime_seconds)
         if(strftime("%d.%m.%Y", records.StartTime_tuple)==strftime("%d.%m.%Y", EndTime_tuple)):
             d1=strftime("%H:%M:%S", EndTime_tuple) #on same day, only show date once
         else:
@@ -1374,12 +1377,15 @@ class frmAdditionalInfoWindow(QMainWindow):
             else:
                 a1=strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTimeWindowEnd_tuple) 
             alarm="<b>Alarm Time Window:</b> "+a0+" - "+a1 + "<br>"
-            if(records.AlarmTime_seconds!=-1): #alarm went off
-                alarm=alarm+"<b>Alarm:</b> Alarm went off on: "+strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTime_tuple)+"<br>"
-                if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
-                    alarm=alarm+"<b>Alarm reason:</b> End of alarm time window<br>"
+            if(records.AlarmTime_seconds!=-1): #alarm was set
+                if(EndTime_seconds>=records.AlarmTime_seconds): #alarm got set off during recording
+                    alarm=alarm+"<b>Alarm:</b> Alarm went off on: "+strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTime_tuple)+"<br>"
+                    if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
+                        alarm=alarm+"<b>Alarm reason:</b> End of alarm time window<br>"
+                    else:
+                        alarm=alarm+"<b>Alarm reason:</b> Movements over trigger level<br>"
                 else:
-                    alarm=alarm+"<b>Alarm reason:</b> Movements over trigger level<br>"
+                    alarm=alarm+"<b>Alarm:</b> Alarm never went off<br>"
             else:
                 alarm=alarm+"<b>Alarm:</b> Alarm never went off<br>"
         else:
@@ -1389,7 +1395,7 @@ class frmAdditionalInfoWindow(QMainWindow):
         "<b>User:</b> "+records.User +"<br>" + \
         "<b>Time:</b> "+d0+" - "+d1+"<br>" + \
         "<b>Duration:</b> "+ diff+"<br>" + \
-        "<b>Record entries:</b> "+str(records.Index)+" (one per "+str(int(records.Sampling_interval*records.Value_smoothing/1000))+" seconds)<br>" +\
+        "<b>Record entries:</b> "+str(records.Index)+" (1 per "+str(int(records.Sampling_interval*records.Value_smoothing/1000))+" seconds)<br>" +\
         "<b>Record version:</b> "+str(records.SWversion) + "<br>" + \
         "<b>Note:</b> "+records.Note+"<br>" +\
         alarm +\
@@ -1658,9 +1664,9 @@ class DisplayStatusDaemon:
             data.DisplayIsOn=True
             if(data.run==True): 
                 if(data.debug==1): print "Update screen & graph"
-                RecordWindow.UpdateScreen()
 #                data.ChangesInGraph=True
                 RecordWindow.Canvas.update()
+                RecordWindow.UpdateScreen()
 
 
 
@@ -1684,10 +1690,12 @@ class MyCanvas(QtGui.QWidget):
     ## 
     ###########################################################################
     def paintEvent(self, event):
-        if(data.debug==1): print "Paint Event"
         if(data.DisplayIsOn==False):
-            if(data.debug==1): print "-> Do not redraw, Display is off!"
+            if(data.debug==1): print "-> o Do not paint event, Display is off!"
             return
+        else:
+            if(data.debug==1): print "-> x paint event"
+
         
         if(data.ScrollToEnd==True): 
             if(data.run==True): RecordWindow.ui.ScrollArea.ensureVisible(data.GraphBitMapLen+100, 0, 0 , 0)
@@ -1714,11 +1722,12 @@ class MyCanvas(QtGui.QWidget):
 ###########################################################################
 ## 
 ###########################################################################        
-def GenerateGraph(self):
-    if(data.debug==1): print "Generate Graph"
+def GenerateGraph(self):    
     if(data.DisplayIsOn==False):
-        if(data.debug==1): print "-> Do not update graph, Display is off!"
+        if(data.debug==1): print "-> o Do not Generate Graph, Display is off!"
         return
+    else:
+        if(data.debug==1): print "-> x Generate Graph"
 
     Xscale=data.arrXscale[data.Xscale]
 #        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  770)
